<template>
  <div class="container-fluid p-4 mb-5 pb-5">

    <div class="row">
      <div class="col-sm-9 m-auto">
        <div class="row">
          <div v-if="data.step === 1" class="col-sm-12 my-3">
            <div class="col-sm-12">
              <h2>{{ t('account.advertise.edit.title') }}</h2>
            </div>
            <advertise-edit-category-step v-model="data.form.category"/>
          </div>
          <div v-if="data.step === 2" class="col-sm-12 my-3">
            <div class="row">
              <div class="col-sm-12">
                <h2>{{ t('account.advertise.edit.title') }}</h2>
              </div>
            </div>
            <advertise-edit-detail-step v-model="data.form" @prevStep="prevStep" :errors="data.errors"/>
            <div class="row">
              <div class="col-sm-12">
                <div class="alert bg-warning">
                  <i class="icon icon-regular-bell-on"></i>
                  <b>{{ t('account.advertise.create.index.alert_title') }}</b><br>
                  <hr>
                  <p>{{ t('account.advertise.create.index.alert_message') }}</p>
                  <ul>
                    <li v-for="index in 6" :key="index">{{
                        t('account.advertise.create.index.alert_list.' + index)
                      }}
                    </li>
                  </ul>
                </div>
              </div>
              <div class="col-sm-12 d-flex align-items-center justify-content-end">
                <button class="btn btn-default" @click="submitForm">
                  {{ t('account.advertise.edit.submit_button') }}
                </button>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script setup>
import {useRoute, useRouter} from "vue-router";
import {onMounted} from "vue";
import {useI18n} from "vue-i18n";

const route = useRoute();
const router = useRouter();

definePageMeta({
  layout: 'default',
  middleware: ['auth']
})

const {t} = useI18n()

const {$api, $validation} = useNuxtApp();

const advertise_id = ref(route.params.advertise)

const data = reactive({
  step: 1,
  form: {
    images: [],
    id: advertise_id.value,
    attributes: [],
    category: {},
    exchange: false,
    price: "",
    title: "",
    content: "",
    hide_mobile: false,
    ai_request: false,
    price_check: false,
    chat_request: false,
    phone_request: false,
    discount_check: false,
    province_id: "",
    city_id: "",
    zone_id: "",
    discount: "",
    discount_start_date: "",
    discount_end_date: "",
    latitude: "",
    longitude: ""
  },
  errors: {
    title: [],
    city_id: [],
    province_id: [],
  },
});

const validateData = () => {
  data.errors.title = {};
  data.errors.city_id = {};
  data.errors.province_id = {};

  data.errors.title = $validation.validate(data.form.title, ['required', 'min:10'], 'عنوان');
  data.errors.city_id = $validation.validate(data.form.city_id, ['required'], 'شهر');
  data.errors.province_id = $validation.validate(data.form.province_id, ['required'], 'استان');
}

const nextStep = () => {
  let check = false;
  if (data.step === 1) {
    if (Object.values(data.form.category).length > 0) {
      check = true;
    }
  }

  if (data.step === 2) {
    check = true;
  }

  if (check) {
    data.step++;
  }
}

const prevStep = () => {
  data.step--;
}

watch(() => data.form.category, (newValue) => {
  nextStep();
});

const getData = () => {
  $api.post('/user/advertise/show', {
    id: advertise_id.value
  }, {
    headers: {
      Authorization: "Bearer " + useCookie('token').value
    }
  }).then((value) => {
    data.form = value.data.data;
    if(data.form.price == 0){
      data.form.price_check = true;
    }
    // nextStep();
  });
}

const checkErrors = () => {
  let output = true;
  Object.values(data.errors).forEach((error) => {
    if (error.length > 0) {
      output = false
    }
  });

  return output;
}

const submitForm = () => {
  validateData();

  if (checkErrors) {
    let images = data.form.images.map((image) => {
      return image.id
    });

    $api.post('/user/advertise/update', {
      id: data.form.id,
      images: images,
      attributes: data.form.attributes,
      category_id: data.form.category.id,
      title: data.form.title,
      price: !data.form.price_check ? data.form.price : '0',
      content: data.form.content,
      latitude: data.form.latitude,
      longitude: data.form.longitude,
      province_id: data.form.province_id,
      city_id: data.form.city_id,
      zone_id: data.form.zone_id,
      exchange: data.form.exchange,
      hide_mobile: data.form.hide_mobile,
      ai_request: data.form.ai_request,
      requested: data.form.requested,
      chat_request: data.form.chat_request,
      discount: data.form.discount,
      discount_start_date: data.form.discount_start_date,
      discount_end_date: data.form.discount_end_date,
      ...(data.form.business_id ? { business_id: data.form.business_id } : {})
    }, {
      headers: {
        Authorization: 'Bearer ' + useCookie('token').value
      }
    }).then((value) => {
      if (value.data.status) {
        router.push('/account/advertise')
      }
    })
  }
}

onMounted(() => {
  getData();
})


</script>

<style scoped>
.container {
  max-width: 600px;
  margin-top: 100px;
  margin-bottom: 100px;
}

.accordion-body {
  padding: 0;
}

.accordion-item {
  width: 100%; /* تنظیم عرض به 100% */

}

.accordion-button:not(.collapsed) {
  color: #333 !important;
  background-color: #fff !important;
  box-shadow: none !important;
}

.accordion-button {
  display: flex; /* استفاده از فلکس باکس برای تنظیم آیکون و متن */
  justify-content: space-between; /* ایجاد فاصله مناسب بین آیکون و متن */
  transition: all 0.2s ease-in-out !important;
  width: 100%;
}

.accordion-button::after {
  margin-left: 0.5rem; /* فاصله بین متن و آیکون */
  content: ''; /* اطمینان از وجود آیکون */
}

button {
  transition: all 0.2s ease-in-out !important;
}


.accordion-button span:hover {
  color: #ff9800 !important;
}

.accordion-button:focus {
  box-shadow: 0 0 0 0.2rem #ff9800;
  outline: none; /* حذف outline پیش‌فرض */
}

</style>